# Minimal Python Module Template
Add your documentation here!

**Quick note: DO NOT CHANGE THE GITHUB WORKFLOWS FOLDER AT ALL, OR .GITIGNORE!!**

#### Pitchfork7 here!
##### adding a tutorial to how to use this :3

1. make copy this repo using the template button!
2. Add your code and rename the folder your project is in!
3. change PKG and Setup.py to include your information and project name!
4. Go to pypi and make an account if you dont already have one!
5. under publishers make a new pending publisher and fill that out!
6. finally make a new release of this repo!

Your now good to Go! :p




Formatting refs:

---

That was a line

# H1
## H2
### H3

```
This is code.
```

```Python
print("This is Python code!")
```

And yeah that's about it.
